]> git.cworth.org Git - scherzo/blobdiff - score.h
Fix high octave numbers (8+) to not be interpreted as 0.
[scherzo] / score.h
diff --git a/score.h b/score.h
index c5d275de0bc4e7614f1effed1ff6ea5d5f42308a..d2de1091c5cecdce1bd6cc6d4bb4d5d513c9e3f1 100644 (file)
--- a/score.h
+++ b/score.h
@@ -24,7 +24,7 @@
 #include <talloc.h>
 #include <cairo.h>
 
-#include "pitch.h"
+#include "scherzo-key.h"
 
 typedef enum score_duration
 {
@@ -84,6 +84,10 @@ score_set_staff_height (score_t *score, int height);
 void
 score_set_width (score_t *score, int width);
 
+/* Set the key for this score */
+void
+score_set_key (score_t *score, pitch_t key);
+
 /* Add a brace to the score, connecting the given number of staves.
  *
  * The staves to be connected are those that will next be added to the
@@ -122,10 +126,13 @@ score_chord_t *
 score_add_chord (score_staff_t *staff,
                 const char * name);
 
/* Remove the given chord from its staff. */
 void
-score_remove_chord (score_chord_t *chord);
+score_staff_remove_chords (score_staff_t *staff);
 
+/* Remove all chords from the score. */
+void
+score_remove_chords (score_t *score);
 
 /* Remove all notes from the given staff. */
 void
@@ -122,10 +126,13 @@ score_chord_t *
                 const char * name);
 
-/* Remove the given chord from its staff. */
+/* Remove all chords from the given staff. */
 void